@@ -1,17 +1,48 @@
 package Catmandu::Importer::PDF;
 
 use Catmandu::Sane;
+use Catmandu::Util qw(:is);
 use Poppler;
 use Moo;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 with 'Catmandu::Importer';
 
-sub _createDocFromFilename {
-    my $filename = $_[0];
+has poppler_glib_version => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    builder => "_build_poppler_glib_version"
+);
+has has_date_bug => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    builder => "_build_has_date_bug"
+);
+has date_offset => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    default => sub {
+        require DateTime;
+        DateTime->now( time_zone => "local" )->offset();
+    }
+);
+sub _build_poppler_glib_version {
+    require ExtUtils::PkgConfig;
+    ExtUtils::PkgConfig->modversion('poppler-glib');
+}
+sub _build_has_date_bug {
+    require version;
+    version->parse( $_[0]->poppler_glib_version() ) < version->parse("0.45.0") ? 1 : 0;
+}
 
-    my $pdf = Poppler::Document->new_from_file( $filename );
+sub _createDoc {
+    my $self = $_[0];
+
+    my $pdf = Poppler::Document->new_from_file( $self->file );
 
     my $num_pages = $pdf->get_n_pages();
 
@@ -47,6 +78,17 @@ sub _createDocFromFilename {
         push @{ $record->{pages} },$p;
     }
 
+    if( $self->has_date_bug() ) {
+
+        if( is_natural( $record->{document}->{creation_date} ) ){
+            $record->{document}->{creation_date} += $self->date_offset();
+        }
+        if( is_natural( $record->{document}->{modification_date} ) ){
+            $record->{document}->{modification_date} += $self->date_offset();
+        }
+
+    }
+
     $record;
 }
 
@@ -57,7 +99,7 @@ sub generator {
         state $doc = undef;
 
         unless($doc){
-            $doc = _createDocFromFilename( $self->file );
+            $doc = $self->_createDoc();
             return $doc;
         }
         return;
@@ -179,7 +221,7 @@ Requires Ubuntu 14 at minimum.
 
 =head1 KNOWN ISSUES
 
-* Due to a bug in older versions of Poppler (bug #94173), the creation_date and modification_date can be returned in local time, instead of utc.
+* Due to a bug in older versions of poppler-glib (bug #94173), the creation_date and modification_date can be returned in local time, instead of utc. This module tries to fix that.
 
 * Some versions of Poppler add form feeds and newlines to a text line, while others don't.
 
