@@ -1,19 +1,50 @@
 package Catmandu::Importer::PDFInfo;
 
 use Catmandu::Sane;
+use Catmandu::Util qw(:is);
 use Poppler;
 use Moo;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 with 'Catmandu::Importer';
 
-sub _createDocFromFilename {
-    my $filename = $_[0];
+has poppler_glib_version => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    builder => "_build_poppler_glib_version"
+);
+has has_date_bug => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    builder => "_build_has_date_bug"
+);
+has date_offset => (
+    is => "ro",
+    init_arg => undef,
+    lazy => 1,
+    default => sub {
+        require DateTime;
+        DateTime->now( time_zone => "local" )->offset();
+    }
+);
+sub _build_poppler_glib_version {
+    require ExtUtils::PkgConfig;
+    ExtUtils::PkgConfig->modversion('poppler-glib');
+}
+sub _build_has_date_bug {
+    require version;
+    version->parse( $_[0]->poppler_glib_version() ) < version->parse("0.45.0") ? 1 : 0;
+}
 
-    my $pdf = Poppler::Document->new_from_file( $filename );
+sub _createDoc {
+    my $self = $_[0];
 
-    +{
+    my $pdf = Poppler::Document->new_from_file( $self->file );
+
+    my $record = +{
         version => $pdf->get_pdf_version_string(),
         title => $pdf->get_title(),
         author => $pdf->get_author(),
@@ -25,6 +56,19 @@ sub _createDocFromFilename {
         modification_date => $pdf->get_modification_date(),
         metadata => $pdf->get_metadata()
     };
+
+    if( $self->has_date_bug() ) {
+
+        if( is_natural( $record->{creation_date} ) ){
+            $record->{creation_date} += $self->date_offset();
+        }
+        if( is_natural( $record->{modification_date} ) ){
+            $record->{modification_date} += $self->date_offset();
+        }
+
+    }
+
+    $record;
 }
 
 sub generator {
@@ -34,7 +78,7 @@ sub generator {
         state $doc;
 
         unless($doc){
-            $doc = _createDocFromFilename( $self->file );
+            $doc = $self->_createDoc();
             return $doc;
         }
         return;
